Tangled Site
============

.. image:: https://travis-ci.org/TangledWeb/tangled.site.png?branch=master
   :target: https://travis-ci.org/TangledWeb/tangled.site

A simple CMS for building a site/blog on top of tangled.web. Serves as an
example of how to use the tangled.web framework.

`Documentation <http://tangledframework.org/docs/tangled.site/>`_
